# Matrix-Alt-Dashboard

**Matrix-Alt-Dashboard** is an extension package to the [Matrix-Alt-Core](https://pypi.org/project/Matrix-Alt-Core/) framework, designed to add a dashboard to your visualization dashboard for your alt agents. The dashboard will run at http://localhost:9000/